A lightweight package to assist in key steps involved in any data analysis workflow:
wrangling the raw data to get it in the needed form,
applying preprocessing steps and statistical transformations, and
compute statistical summaries of data properties and distributions.
It is also the data wrangling backend for packages in 'easystats' ecosystem. Reference: Patil et al. (2022) tools:::Rd_expr_doi("10.21105/joss.04684").
Maintainer: Etienne Bacher [email protected] (ORCID)
Authors:
Indrajeet Patil [email protected] (ORCID)
Dominique Makowski [email protected] (ORCID)
Daniel Lüdecke [email protected] (ORCID)
Mattan S. Ben-Shachar [email protected] (ORCID)
Brenton M. Wiernik [email protected] (ORCID)
Other contributors:
Rémi Thériault [email protected] (ORCID) [contributor]
Thomas J. Faulkenberry [email protected] [reviewer]
Robert Garrett [email protected] [reviewer]
datawizard
Useful links: